Module machine

Module machine 

Modules

apply_configuration_request
Nested message and enum types in ApplyConfigurationRequest.
connect_record
Nested message and enum types in ConnectRecord.
etcd_member_alarm
Nested message and enum types in EtcdMemberAlarm.
list_request
Nested message and enum types in ListRequest.
machine_config
Nested message and enum types in MachineConfig.
machine_service_client
Generated client implementations.
machine_service_server
Generated server implementations.
machine_status_event
Nested message and enum types in MachineStatusEvent.
netstat_request
Nested message and enum types in NetstatRequest.
phase_event
Nested message and enum types in PhaseEvent.
reboot_request
Nested message and enum types in RebootRequest.
reset_request
Nested message and enum types in ResetRequest.
sequence_event
Nested message and enum types in SequenceEvent.
service_state_event
Nested message and enum types in ServiceStateEvent.
task_event
Nested message and enum types in TaskEvent.
upgrade_request
Nested message and enum types in UpgradeRequest.

Structs

AddressEvent
AddressEvent reports node endpoints aggregated from k8s.Endpoints and network.Hostname.
ApplyConfiguration
ApplyConfigurationResponse describes the response to a configuration request.
ApplyConfigurationRequest
rpc applyConfiguration ApplyConfiguration describes a request to assert a new configuration upon a node.
ApplyConfigurationResponse
Bootstrap
The bootstrap message containing the bootstrap status.
BootstrapRequest
rpc Bootstrap
BootstrapResponse
BpfInstruction
ClusterConfig
ClusterNetworkConfig
CniConfig
ConfigLoadErrorEvent
ConfigLoadErrorEvent is reported when the config loading has failed.
ConfigValidationErrorEvent
ConfigValidationErrorEvent is reported when config validation has failed.
ConnectRecord
Container
The messages message containing the requested containers.
ContainerInfo
The messages message containing the requested containers.
ContainersRequest
ContainersResponse
ControlPlaneConfig
CopyRequest
CopyRequest describes a request to copy data out of Talos node
CpUsFreqStats
CpUsInfo
CpuFreqStats
CpuFreqStatsResponse
CpuInfo
CpuInfoResponse
CpuStat
DhcpOptionsConfig
DiskStat
DiskStats
DiskStatsResponse
DiskUsageInfo
DiskUsageInfo describes a file or directory’s information for du command
DiskUsageRequest
DiskUsageRequest describes a request to list disk usage of directories and regular files
DmesgRequest
dmesg
EtcdAlarm
EtcdAlarmDisarm
EtcdAlarmDisarmResponse
EtcdAlarmListResponse
EtcdClusterDowngrade
EtcdDefragment
EtcdDefragmentResponse
EtcdDowngradeCancel
EtcdDowngradeCancelResponse
EtcdDowngradeEnable
EtcdDowngradeEnableRequest
EtcdDowngradeEnableResponse
EtcdDowngradeValidate
EtcdDowngradeValidateRequest
EtcdDowngradeValidateResponse
EtcdForfeitLeadership
EtcdForfeitLeadershipRequest
EtcdForfeitLeadershipResponse
EtcdLeaveCluster
EtcdLeaveClusterRequest
EtcdLeaveClusterResponse
EtcdMember
EtcdMember describes a single etcd member.
EtcdMemberAlarm
EtcdMemberListRequest
EtcdMemberListResponse
EtcdMemberStatus
EtcdMembers
EtcdMembers contains the list of members registered on the host.
EtcdRecover
EtcdRecoverResponse
EtcdRemoveMember
EtcdRemoveMemberById
EtcdRemoveMemberByIdRequest
EtcdRemoveMemberByIdResponse
EtcdRemoveMemberRequest
EtcdRemoveMemberResponse
EtcdSnapshotRequest
EtcdStatus
EtcdStatusResponse
Event
EventsRequest
FeaturesInfo
FeaturesInfo describes individual Talos features that can be switched on or off.
FileInfo
FileInfo describes a file or directory’s information
GenerateClientConfiguration
GenerateClientConfigurationRequest
GenerateClientConfigurationResponse
Hostname
HostnameResponse
ImageListRequest
ImageListResponse
ImagePull
ImagePullRequest
ImagePullResponse
InstallConfig
ListRequest
ListRequest describes a request to list the contents of a directory.
LoadAvg
LoadAvgResponse
LogsContainer
LogsContainer describes all available registered log containers.
LogsContainersResponse
LogsRequest
rpc logs The request message containing the process name.
MachineConfig
MachineStatusEvent
MachineStatusEvent reports changes to the MachineStatus resource.
MemInfo
Memory
MemoryResponse
MetaDelete
MetaDeleteRequest
MetaDeleteResponse
MetaWrite
MetaWriteRequest
MetaWriteResponse
MountStat
The messages message containing the requested processes.
Mounts
The messages message containing the requested df stats.
MountsResponse
NetDev
Netstat
NetstatRequest
NetstatResponse
NetworkConfig
NetworkDeviceConfig
NetworkDeviceStats
NetworkDeviceStatsResponse
PacketCaptureRequest
PhaseEvent
PlatformInfo
Process
ProcessInfo
ProcessesResponse
rpc processes
ReadRequest
Reboot
The reboot message containing the reboot status.
RebootRequest
rpc reboot
RebootResponse
Reset
The reset message containing the restart status.
ResetPartitionSpec
rpc reset
ResetRequest
ResetResponse
Restart
RestartEvent
RestartRequest
rpc restart The request message containing the process to restart.
RestartResponse
The messages message containing the restart status.
Rollback
RollbackRequest
rpc rollback
RollbackResponse
RouteConfig
SequenceEvent
rpc events
ServiceEvent
ServiceEvents
ServiceHealth
ServiceInfo
ServiceList
rpc servicelist
ServiceListResponse
ServiceRestart
ServiceRestartRequest
ServiceRestartResponse
ServiceStart
ServiceStartRequest
rpc servicestart
ServiceStartResponse
ServiceStateEvent
ServiceStop
ServiceStopRequest
ServiceStopResponse
Shutdown
rpc shutdown The messages message containing the shutdown status.
ShutdownRequest
ShutdownResponse
SoftIrqStat
Stat
The messages message containing the requested stat.
Stats
The messages message containing the requested stats.
StatsRequest
The request message containing the containerd namespace.
StatsResponse
SystemStat
SystemStatResponse
TaskEvent
Upgrade
UpgradeRequest
rpc upgrade
UpgradeResponse
Version
VersionInfo
VersionResponse
Xattr