MachineService

Trait MachineService 

pub trait MachineService:
    Send
    + Sync
    + 'static {
    type CopyStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type DmesgStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type EventsStream: Stream<Item = Result<Event, Status>> + Send + 'static;
    type EtcdSnapshotStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type KubeconfigStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type ListStream: Stream<Item = Result<FileInfo, Status>> + Send + 'static;
    type DiskUsageStream: Stream<Item = Result<DiskUsageInfo, Status>> + Send + 'static;
    type LogsStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type ReadStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type PacketCaptureStream: Stream<Item = Result<Data, Status>> + Send + 'static;
    type ImageListStream: Stream<Item = Result<ImageListResponse, Status>> + Send + 'static;

Show 54 methods // Required methods fn apply_configuration<'life0, 'async_trait>( &'life0 self, request: Request<ApplyConfigurationRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ApplyConfigurationResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn bootstrap<'life0, 'async_trait>( &'life0 self, request: Request<BootstrapRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<BootstrapResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn containers<'life0, 'async_trait>( &'life0 self, request: Request<ContainersRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ContainersResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn copy<'life0, 'async_trait>( &'life0 self, request: Request<CopyRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::CopyStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn cpu_freq_stats<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<CpuFreqStatsResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn cpu_info<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<CpuInfoResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn disk_stats<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<DiskStatsResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn dmesg<'life0, 'async_trait>( &'life0 self, request: Request<DmesgRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DmesgStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn events<'life0, 'async_trait>( &'life0 self, request: Request<EventsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::EventsStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_member_list<'life0, 'async_trait>( &'life0 self, request: Request<EtcdMemberListRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdMemberListResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_remove_member_by_id<'life0, 'async_trait>( &'life0 self, request: Request<EtcdRemoveMemberByIdRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdRemoveMemberByIdResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_leave_cluster<'life0, 'async_trait>( &'life0 self, request: Request<EtcdLeaveClusterRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdLeaveClusterResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_forfeit_leadership<'life0, 'async_trait>( &'life0 self, request: Request<EtcdForfeitLeadershipRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdForfeitLeadershipResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_recover<'life0, 'async_trait>( &'life0 self, request: Request<Streaming<Data>>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdRecoverResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_snapshot<'life0, 'async_trait>( &'life0 self, request: Request<EtcdSnapshotRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::EtcdSnapshotStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_alarm_list<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdAlarmListResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_alarm_disarm<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdAlarmDisarmResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_defragment<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDefragmentResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_status<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdStatusResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_downgrade_validate<'life0, 'async_trait>( &'life0 self, request: Request<EtcdDowngradeValidateRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDowngradeValidateResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_downgrade_enable<'life0, 'async_trait>( &'life0 self, request: Request<EtcdDowngradeEnableRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDowngradeEnableResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn etcd_downgrade_cancel<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDowngradeCancelResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn hostname<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<HostnameResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn kubeconfig<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::KubeconfigStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn list<'life0, 'async_trait>( &'life0 self, request: Request<ListRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::ListStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn disk_usage<'life0, 'async_trait>( &'life0 self, request: Request<DiskUsageRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DiskUsageStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn load_avg<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<LoadAvgResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn logs<'life0, 'async_trait>( &'life0 self, request: Request<LogsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::LogsStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn logs_containers<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<LogsContainersResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn memory<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<MemoryResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn mounts<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<MountsResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn network_device_stats<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<NetworkDeviceStatsResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn processes<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<ProcessesResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn read<'life0, 'async_trait>( &'life0 self, request: Request<ReadRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::ReadStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn reboot<'life0, 'async_trait>( &'life0 self, request: Request<RebootRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RebootResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn restart<'life0, 'async_trait>( &'life0 self, request: Request<RestartRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RestartResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn rollback<'life0, 'async_trait>( &'life0 self, request: Request<RollbackRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RollbackResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn reset<'life0, 'async_trait>( &'life0 self, request: Request<ResetRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ResetResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn service_list<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceListResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn service_restart<'life0, 'async_trait>( &'life0 self, request: Request<ServiceRestartRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceRestartResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn service_start<'life0, 'async_trait>( &'life0 self, request: Request<ServiceStartRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceStartResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn service_stop<'life0, 'async_trait>( &'life0 self, request: Request<ServiceStopRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceStopResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn shutdown<'life0, 'async_trait>( &'life0 self, request: Request<ShutdownRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ShutdownResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn stats<'life0, 'async_trait>( &'life0 self, request: Request<StatsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<StatsResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn system_stat<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<SystemStatResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn upgrade<'life0, 'async_trait>( &'life0 self, request: Request<UpgradeRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<UpgradeResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn version<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<VersionResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn generate_client_configuration<'life0, 'async_trait>( &'life0 self, request: Request<GenerateClientConfigurationRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<GenerateClientConfigurationResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn packet_capture<'life0, 'async_trait>( &'life0 self, request: Request<PacketCaptureRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::PacketCaptureStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn netstat<'life0, 'async_trait>( &'life0 self, request: Request<NetstatRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<NetstatResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn meta_write<'life0, 'async_trait>( &'life0 self, request: Request<MetaWriteRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<MetaWriteResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn meta_delete<'life0, 'async_trait>( &'life0 self, request: Request<MetaDeleteRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<MetaDeleteResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn image_list<'life0, 'async_trait>( &'life0 self, request: Request<ImageListRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::ImageListStream>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn image_pull<'life0, 'async_trait>( &'life0 self, request: Request<ImagePullRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ImagePullResponse>, Status>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait;
}
Generated trait containing gRPC methods that should be implemented for use with MachineServiceServer.

Required Associated Types

type CopyStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the Copy method.

type DmesgStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the Dmesg method.

type EventsStream: Stream<Item = Result<Event, Status>> + Send + 'static

Server streaming response type for the Events method.

type EtcdSnapshotStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the EtcdSnapshot method.

type KubeconfigStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the Kubeconfig method.

type ListStream: Stream<Item = Result<FileInfo, Status>> + Send + 'static

Server streaming response type for the List method.

type DiskUsageStream: Stream<Item = Result<DiskUsageInfo, Status>> + Send + 'static

Server streaming response type for the DiskUsage method.

type LogsStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the Logs method.

type ReadStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the Read method.

type PacketCaptureStream: Stream<Item = Result<Data, Status>> + Send + 'static

Server streaming response type for the PacketCapture method.

type ImageListStream: Stream<Item = Result<ImageListResponse, Status>> + Send + 'static

Server streaming response type for the ImageList method.

Required Methods

fn apply_configuration<'life0, 'async_trait>( &'life0 self, request: Request<ApplyConfigurationRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ApplyConfigurationResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn bootstrap<'life0, 'async_trait>( &'life0 self, request: Request<BootstrapRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<BootstrapResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Bootstrap method makes control plane node enter etcd bootstrap mode. Node aborts etcd join sequence and creates single-node etcd cluster. If recover_etcd argument is specified, etcd is recovered from a snapshot uploaded with EtcdRecover.

fn containers<'life0, 'async_trait>( &'life0 self, request: Request<ContainersRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ContainersResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn copy<'life0, 'async_trait>( &'life0 self, request: Request<CopyRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::CopyStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn cpu_freq_stats<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<CpuFreqStatsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn cpu_info<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<CpuInfoResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn disk_stats<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<DiskStatsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn dmesg<'life0, 'async_trait>( &'life0 self, request: Request<DmesgRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DmesgStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn events<'life0, 'async_trait>( &'life0 self, request: Request<EventsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::EventsStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn etcd_member_list<'life0, 'async_trait>( &'life0 self, request: Request<EtcdMemberListRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdMemberListResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn etcd_remove_member_by_id<'life0, 'async_trait>( &'life0 self, request: Request<EtcdRemoveMemberByIdRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdRemoveMemberByIdResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdRemoveMemberByID removes a member from the etcd cluster identified by member ID. This API should be used to remove members which donโ€™t have an associated Talos node anymore. To remove a member with a running Talos node, use EtcdLeaveCluster API on the node to be removed.

fn etcd_leave_cluster<'life0, 'async_trait>( &'life0 self, request: Request<EtcdLeaveClusterRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdLeaveClusterResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn etcd_forfeit_leadership<'life0, 'async_trait>( &'life0 self, request: Request<EtcdForfeitLeadershipRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdForfeitLeadershipResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn etcd_recover<'life0, 'async_trait>( &'life0 self, request: Request<Streaming<Data>>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdRecoverResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdRecover method uploads etcd data snapshot created with EtcdSnapshot to the node. Snapshot can be later used to recover the cluster via Bootstrap method.

fn etcd_snapshot<'life0, 'async_trait>( &'life0 self, request: Request<EtcdSnapshotRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::EtcdSnapshotStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdSnapshot method creates etcd data snapshot (backup) from the local etcd instance and streams it back to the client. This method is available only on control plane nodes (which run etcd).

fn etcd_alarm_list<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdAlarmListResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdAlarmList lists etcd alarms for the current node. This method is available only on control plane nodes (which run etcd).

fn etcd_alarm_disarm<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdAlarmDisarmResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdAlarmDisarm disarms etcd alarms for the current node. This method is available only on control plane nodes (which run etcd).

fn etcd_defragment<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDefragmentResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdDefragment defragments etcd data directory for the current node. Defragmentation is a resource-heavy operation, so it should only run on a specific node. This method is available only on control plane nodes (which run etcd).

fn etcd_status<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdStatusResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdStatus returns etcd status for the current member. This method is available only on control plane nodes (which run etcd).

fn etcd_downgrade_validate<'life0, 'async_trait>( &'life0 self, request: Request<EtcdDowngradeValidateRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDowngradeValidateResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdDowngradeValidate validates etcd cluster for downgrade to a specific version. This method is available only on control plane nodes (which run etcd).

fn etcd_downgrade_enable<'life0, 'async_trait>( &'life0 self, request: Request<EtcdDowngradeEnableRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDowngradeEnableResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdDowngradeEnable enables etcd cluster downgrade to a specific version. This method is available only on control plane nodes (which run etcd).

fn etcd_downgrade_cancel<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<EtcdDowngradeCancelResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

EtcdDowngradeCancel cancels etcd cluster downgrade that is in progress. This method is available only on control plane nodes (which run etcd).

fn hostname<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<HostnameResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn kubeconfig<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::KubeconfigStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn list<'life0, 'async_trait>( &'life0 self, request: Request<ListRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::ListStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn disk_usage<'life0, 'async_trait>( &'life0 self, request: Request<DiskUsageRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DiskUsageStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn load_avg<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<LoadAvgResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn logs<'life0, 'async_trait>( &'life0 self, request: Request<LogsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::LogsStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn logs_containers<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<LogsContainersResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn memory<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<MemoryResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn mounts<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<MountsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn network_device_stats<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<NetworkDeviceStatsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn processes<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<ProcessesResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn read<'life0, 'async_trait>( &'life0 self, request: Request<ReadRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::ReadStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn reboot<'life0, 'async_trait>( &'life0 self, request: Request<RebootRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RebootResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn restart<'life0, 'async_trait>( &'life0 self, request: Request<RestartRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RestartResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn rollback<'life0, 'async_trait>( &'life0 self, request: Request<RollbackRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RollbackResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn reset<'life0, 'async_trait>( &'life0 self, request: Request<ResetRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ResetResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn service_list<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceListResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn service_restart<'life0, 'async_trait>( &'life0 self, request: Request<ServiceRestartRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceRestartResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn service_start<'life0, 'async_trait>( &'life0 self, request: Request<ServiceStartRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceStartResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn service_stop<'life0, 'async_trait>( &'life0 self, request: Request<ServiceStopRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ServiceStopResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn shutdown<'life0, 'async_trait>( &'life0 self, request: Request<ShutdownRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ShutdownResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn stats<'life0, 'async_trait>( &'life0 self, request: Request<StatsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<StatsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn system_stat<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<SystemStatResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn upgrade<'life0, 'async_trait>( &'life0 self, request: Request<UpgradeRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<UpgradeResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn version<'life0, 'async_trait>( &'life0 self, request: Request<()>, ) -> Pin<Box<dyn Future<Output = Result<Response<VersionResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn generate_client_configuration<'life0, 'async_trait>( &'life0 self, request: Request<GenerateClientConfigurationRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<GenerateClientConfigurationResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

GenerateClientConfiguration generates talosctl client configuration (talosconfig).

fn packet_capture<'life0, 'async_trait>( &'life0 self, request: Request<PacketCaptureRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::PacketCaptureStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

PacketCapture performs packet capture and streams back pcap file.

fn netstat<'life0, 'async_trait>( &'life0 self, request: Request<NetstatRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<NetstatResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Netstat provides information about network connections.

fn meta_write<'life0, 'async_trait>( &'life0 self, request: Request<MetaWriteRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<MetaWriteResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

MetaWrite writes a META key-value pair.

fn meta_delete<'life0, 'async_trait>( &'life0 self, request: Request<MetaDeleteRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<MetaDeleteResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

MetaDelete deletes a META key.

fn image_list<'life0, 'async_trait>( &'life0 self, request: Request<ImageListRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::ImageListStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

ImageList lists images in the CRI.

fn image_pull<'life0, 'async_trait>( &'life0 self, request: Request<ImagePullRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ImagePullResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

ImagePull pulls an image into the CRI.

Implementors