ApplyConfigurationRequest

Struct ApplyConfigurationRequest 

pub struct ApplyConfigurationRequest {
    pub data: Vec<u8>,
    pub mode: i32,
    pub dry_run: bool,
    pub try_mode_timeout: Option<Duration>,
}
rpc applyConfiguration ApplyConfiguration describes a request to assert a new configuration upon a node.

Fields

data: Vec<u8>mode: i32dry_run: booltry_mode_timeout: Option<Duration>

Implementations

Source

impl ApplyConfigurationRequest

pub fn mode(&self) -> Mode

Returns the enum value of mode, or the default if the field is set to an invalid enum value.

pub fn set_mode(&mut self, value: Mode)

Sets mode to the provided enum value.