ContainersRequest

Struct ContainersRequest 

pub struct ContainersRequest {
    pub namespace: String,
    pub driver: i32,
}

Fields

namespace: Stringdriver: i32

driver might be default “containerd” or “cri”

Implementations

Source

impl ContainersRequest

pub fn driver(&self) -> ContainerDriver

Returns the enum value of driver, or the default if the field is set to an invalid enum value.

pub fn set_driver(&mut self, value: ContainerDriver)

Sets driver to the provided enum value.