pub struct CpuInfo {Show 26 fields
pub processor: u32,
pub vendor_id: String,
pub cpu_family: String,
pub model: String,
pub model_name: String,
pub stepping: String,
pub microcode: String,
pub cpu_mhz: f64,
pub cache_size: String,
pub physical_id: String,
pub siblings: u32,
pub core_id: String,
pub cpu_cores: u32,
pub apic_id: String,
pub initial_apic_id: String,
pub fpu: String,
pub fpu_exception: String,
pub cpu_id_level: u32,
pub wp: String,
pub flags: Vec<String>,
pub bugs: Vec<String>,
pub bogo_mips: f64,
pub cl_flush_size: u32,
pub cache_alignment: u32,
pub address_sizes: String,
pub power_management: String,
}Fields
processor: u32vendor_id: Stringcpu_family: Stringmodel: Stringmodel_name: Stringstepping: Stringmicrocode: Stringcpu_mhz: f64cache_size: Stringphysical_id: Stringsiblings: u32core_id: Stringcpu_cores: u32apic_id: Stringinitial_apic_id: Stringfpu: Stringfpu_exception: Stringcpu_id_level: u32wp: Stringflags: Vec<String>bugs: Vec<String>bogo_mips: f64cl_flush_size: u32cache_alignment: u32address_sizes: Stringpower_management: StringTrait Implementations
Sourceimpl From<CpuInfo> for CpuInfo
impl From<CpuInfo> for CpuInfo
Sourcefn from(proto: ProtoCpuInfo) -> Self
fn from(proto: ProtoCpuInfo) -> Self
Converts to this type from the input type.
Sourceimpl Message for CpuInfo
impl Message for CpuInfo
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for CpuInfo