pub struct DiskStat {Show 16 fields
pub name: String,
pub read_completed: u64,
pub read_merged: u64,
pub read_sectors: u64,
pub read_time_ms: u64,
pub write_completed: u64,
pub write_merged: u64,
pub write_sectors: u64,
pub write_time_ms: u64,
pub io_in_progress: u64,
pub io_time_ms: u64,
pub io_time_weighted_ms: u64,
pub discard_completed: u64,
pub discard_merged: u64,
pub discard_sectors: u64,
pub discard_time_ms: u64,
}Fields
name: Stringread_completed: u64read_merged: u64read_sectors: u64read_time_ms: u64write_completed: u64write_merged: u64write_sectors: u64write_time_ms: u64io_in_progress: u64io_time_ms: u64io_time_weighted_ms: u64discard_completed: u64discard_merged: u64discard_sectors: u64discard_time_ms: u64Trait Implementations
Sourceimpl From<DiskStat> for DiskStat
impl From<DiskStat> for DiskStat
Sourcefn from(proto: ProtoDiskStat) -> Self
fn from(proto: ProtoDiskStat) -> Self
Converts to this type from the input type.
Sourceimpl Message for DiskStat
impl Message for DiskStat
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl Eq for DiskStat
impl StructuralPartialEq for DiskStat