pub struct EtcdForfeitLeadershipResponse {
pub messages: Vec<EtcdForfeitLeadership>,
}Fields
messages: Vec<EtcdForfeitLeadership>Trait Implementations
Sourceimpl Clone for EtcdForfeitLeadershipResponse
impl Clone for EtcdForfeitLeadershipResponse
Sourcefn clone(&self) -> EtcdForfeitLeadershipResponse
fn clone(&self) -> EtcdForfeitLeadershipResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<EtcdForfeitLeadershipResponse> for EtcdForfeitLeadershipResponse
impl From<EtcdForfeitLeadershipResponse> for EtcdForfeitLeadershipResponse
Sourcefn from(proto: ProtoEtcdForfeitLeadershipResponse) -> Self
fn from(proto: ProtoEtcdForfeitLeadershipResponse) -> Self
Converts to this type from the input type.
Sourceimpl Message for EtcdForfeitLeadershipResponse
impl Message for EtcdForfeitLeadershipResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EtcdForfeitLeadershipResponse
impl PartialEq for EtcdForfeitLeadershipResponse
Sourcefn eq(&self, other: &EtcdForfeitLeadershipResponse) -> bool
fn eq(&self, other: &EtcdForfeitLeadershipResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EtcdForfeitLeadershipResponse