pub struct EtcdMemberStatus {
pub storage_version: String,
pub member_id: u64,
pub protocol_version: String,
pub db_size: i64,
pub db_size_in_use: i64,
pub leader: u64,
pub raft_index: u64,
pub raft_term: u64,
pub raft_applied_index: u64,
pub errors: Vec<String>,
pub is_learner: bool,
}Fields
storage_version: Stringmember_id: u64protocol_version: Stringdb_size: i64db_size_in_use: i64leader: u64raft_index: u64raft_term: u64raft_applied_index: u64errors: Vec<String>is_learner: boolTrait Implementations
Sourceimpl Clone for EtcdMemberStatus
impl Clone for EtcdMemberStatus
Sourcefn clone(&self) -> EtcdMemberStatus
fn clone(&self) -> EtcdMemberStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EtcdMemberStatus
impl Debug for EtcdMemberStatus
Sourceimpl Default for EtcdMemberStatus
impl Default for EtcdMemberStatus
Sourceimpl From<EtcdMemberStatus> for EtcdMemberStatus
impl From<EtcdMemberStatus> for EtcdMemberStatus
Sourcefn from(proto: ProtoEtcdMemberStatus) -> Self
fn from(proto: ProtoEtcdMemberStatus) -> Self
Converts to this type from the input type.
Sourceimpl Hash for EtcdMemberStatus
impl Hash for EtcdMemberStatus
Sourceimpl Message for EtcdMemberStatus
impl Message for EtcdMemberStatus
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EtcdMemberStatus
impl PartialEq for EtcdMemberStatus
impl Eq for EtcdMemberStatus
impl StructuralPartialEq for EtcdMemberStatus