pub struct EtcdMembers {
pub metadata: Option<Metadata>,
pub legacy_members: Vec<String>,
pub members: Vec<EtcdMember>,
}Expand description
EtcdMembers contains the list of members registered on the host.
Fields
metadata: Option<Metadata>legacy_members: Vec<String>list of member hostnames.
members: Vec<EtcdMember>the list of etcd members registered on the node.