pub struct EtcdRemoveMemberByIdRequest {
pub member_id: u64,
}Fields
member_id: u64Trait Implementations
Sourceimpl Clone for EtcdRemoveMemberByIdRequest
impl Clone for EtcdRemoveMemberByIdRequest
Sourcefn clone(&self) -> EtcdRemoveMemberByIdRequest
fn clone(&self) -> EtcdRemoveMemberByIdRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EtcdRemoveMemberByIdRequest
impl Debug for EtcdRemoveMemberByIdRequest
Sourceimpl From<EtcdRemoveMemberByIdRequest> for EtcdRemoveMemberByIdRequest
impl From<EtcdRemoveMemberByIdRequest> for EtcdRemoveMemberByIdRequest
Sourcefn from(req: EtcdRemoveMemberByIdRequest) -> Self
fn from(req: EtcdRemoveMemberByIdRequest) -> Self
Converts to this type from the input type.
Sourceimpl Hash for EtcdRemoveMemberByIdRequest
impl Hash for EtcdRemoveMemberByIdRequest
Sourceimpl Message for EtcdRemoveMemberByIdRequest
impl Message for EtcdRemoveMemberByIdRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl Copy for EtcdRemoveMemberByIdRequest
impl Eq for EtcdRemoveMemberByIdRequest
impl StructuralPartialEq for EtcdRemoveMemberByIdRequest