pub struct ImageListRequest {
pub namespace: i32,
}Fields
namespace: i32Containerd namespace to use.
Implementations
Sourceimpl ImageListRequest
impl ImageListRequest
Sourcepub fn namespace(&self) -> ContainerdNamespace
pub fn namespace(&self) -> ContainerdNamespace
Returns the enum value of namespace, or the default if the field is set to an invalid enum value.
Sourcepub fn set_namespace(&mut self, value: ContainerdNamespace)
pub fn set_namespace(&mut self, value: ContainerdNamespace)
Sets namespace to the provided enum value.