ListRequest

Struct ListRequest 

pub struct ListRequest {
    pub root: String,
    pub recurse: bool,
    pub recursion_depth: i32,
    pub types: Vec<i32>,
    pub report_xattrs: bool,
}
ListRequest describes a request to list the contents of a directory.

Fields

root: String

Root indicates the root directory for the list. If not indicated, ‘/’ is presumed.

recurse: bool

Recurse indicates that subdirectories should be recursed.

recursion_depth: i32

RecursionDepth indicates how many levels of subdirectories should be recursed. The default (0) indicates that no limit should be enforced.

types: Vec<i32>

Types indicates what file type should be returned. If not indicated, all files will be returned.

report_xattrs: bool

Report xattrs

Implementations

Source

impl ListRequest

pub fn types(&self) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Type>>

Returns an iterator which yields the valid enum values contained in types.

pub fn push_types(&mut self, value: Type)

Appends the provided enum value to types.