pub struct LogsRequest {
pub namespace: String,
pub id: String,
pub driver: i32,
pub follow: bool,
pub tail_lines: i32,
}Expand description
rpc logs The request message containing the process name.
Fields
namespace: Stringid: Stringdriver: i32driver might be default “containerd” or “cri”
follow: booltail_lines: i32Implementations
Sourceimpl LogsRequest
impl LogsRequest
Sourcepub fn driver(&self) -> ContainerDriver
pub fn driver(&self) -> ContainerDriver
Returns the enum value of driver, or the default if the field is set to an invalid enum value.
Sourcepub fn set_driver(&mut self, value: ContainerDriver)
pub fn set_driver(&mut self, value: ContainerDriver)
Sets driver to the provided enum value.