pub struct MachineStatusEvent {
pub stage: i32,
pub status: Option<MachineStatus>,
}Expand description
MachineStatusEvent reports changes to the MachineStatus resource.
Fields
stage: i32status: Option<MachineStatus>Implementations
Sourceimpl MachineStatusEvent
impl MachineStatusEvent
Sourcepub fn stage(&self) -> MachineStage
pub fn stage(&self) -> MachineStage
Returns the enum value of stage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stage(&mut self, value: MachineStage)
pub fn set_stage(&mut self, value: MachineStage)
Sets stage to the provided enum value.