pub struct MemInfo {Show 48 fields
pub memtotal: u64,
pub memfree: u64,
pub memavailable: u64,
pub buffers: u64,
pub cached: u64,
pub swapcached: u64,
pub active: u64,
pub inactive: u64,
pub activeanon: u64,
pub inactiveanon: u64,
pub activefile: u64,
pub inactivefile: u64,
pub unevictable: u64,
pub mlocked: u64,
pub swaptotal: u64,
pub swapfree: u64,
pub dirty: u64,
pub writeback: u64,
pub anonpages: u64,
pub mapped: u64,
pub shmem: u64,
pub slab: u64,
pub sreclaimable: u64,
pub sunreclaim: u64,
pub kernelstack: u64,
pub pagetables: u64,
pub nfsunstable: u64,
pub bounce: u64,
pub writebacktmp: u64,
pub commitlimit: u64,
pub committedas: u64,
pub vmalloctotal: u64,
pub vmallocused: u64,
pub vmallocchunk: u64,
pub hardwarecorrupted: u64,
pub anonhugepages: u64,
pub shmemhugepages: u64,
pub shmempmdmapped: u64,
pub cmatotal: u64,
pub cmafree: u64,
pub hugepagestotal: u64,
pub hugepagesfree: u64,
pub hugepagesrsvd: u64,
pub hugepagessurp: u64,
pub hugepagesize: u64,
pub directmap4k: u64,
pub directmap2m: u64,
pub directmap1g: u64,
}Fields
memtotal: u64memfree: u64memavailable: u64buffers: u64cached: u64swapcached: u64active: u64inactive: u64activeanon: u64inactiveanon: u64activefile: u64inactivefile: u64unevictable: u64mlocked: u64swaptotal: u64swapfree: u64dirty: u64writeback: u64anonpages: u64mapped: u64shmem: u64slab: u64sreclaimable: u64sunreclaim: u64kernelstack: u64pagetables: u64nfsunstable: u64bounce: u64writebacktmp: u64commitlimit: u64committedas: u64vmalloctotal: u64vmallocused: u64vmallocchunk: u64hardwarecorrupted: u64anonhugepages: u64shmemhugepages: u64shmempmdmapped: u64cmatotal: u64cmafree: u64hugepagestotal: u64hugepagesfree: u64hugepagesrsvd: u64hugepagessurp: u64hugepagesize: u64directmap4k: u64directmap2m: u64directmap1g: u64Trait Implementations
Sourceimpl Message for MemInfo
impl Message for MemInfo
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl Copy for MemInfo
impl Eq for MemInfo
impl StructuralPartialEq for MemInfo