pub struct SoftIrqStat {
pub hi: u64,
pub timer: u64,
pub net_tx: u64,
pub net_rx: u64,
pub block: u64,
pub block_io_poll: u64,
pub tasklet: u64,
pub sched: u64,
pub hrtimer: u64,
pub rcu: u64,
}Fields
hi: u64timer: u64net_tx: u64net_rx: u64block: u64block_io_poll: u64tasklet: u64sched: u64hrtimer: u64rcu: u64Trait Implementations
Sourceimpl Clone for SoftIrqStat
impl Clone for SoftIrqStat
Sourcefn clone(&self) -> SoftIrqStat
fn clone(&self) -> SoftIrqStat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SoftIrqStat
impl Debug for SoftIrqStat
Sourceimpl Default for SoftIrqStat
impl Default for SoftIrqStat
Sourceimpl Hash for SoftIrqStat
impl Hash for SoftIrqStat
Sourceimpl Message for SoftIrqStat
impl Message for SoftIrqStat
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SoftIrqStat
impl PartialEq for SoftIrqStat
impl Copy for SoftIrqStat
impl Eq for SoftIrqStat
impl StructuralPartialEq for SoftIrqStat