pub struct SpanFactory { /* private fields */ }Expand description
Span factory for creating consistent spans across the client.
Implementations
Sourceimpl SpanFactory
impl SpanFactory
Sourcepub fn new(config: TracingConfig) -> Self
pub fn new(config: TracingConfig) -> Self
Create a new span factory with the given configuration.
Sourcepub fn create_span(&self, method: &str, endpoint: &str) -> TalosSpan
pub fn create_span(&self, method: &str, endpoint: &str) -> TalosSpan
Create a span for a Talos API call.
Sourcepub fn create_etcd_span(&self, method: &str, endpoint: &str) -> TalosSpan
pub fn create_etcd_span(&self, method: &str, endpoint: &str) -> TalosSpan
Create a span for an etcd API call.
Sourcepub fn config(&self) -> &TracingConfig
pub fn config(&self) -> &TracingConfig
Get the configuration.