pub struct DiskUsageRequest {
pub recursion_depth: i32,
pub all: bool,
pub threshold: i64,
pub paths: Vec<String>,
}Expand description
DiskUsageRequest describes a request to list disk usage of directories and regular files
Fields
recursion_depth: i32RecursionDepth indicates how many levels of subdirectories should be recursed. The default (0) indicates that no limit should be enforced.
all: boolAll write sizes for all files, not just directories.
threshold: i64Threshold exclude entries smaller than SIZE if positive, or entries greater than SIZE if negative.
paths: Vec<String>DiskUsagePaths is the list of directories to calculate disk usage for.